One Night in Gothenburg Gothenburg, Sweden November 3rd 2001 Sten Düring Deck Name: Firepower Crypt (12 cards, min=18, max=39, avg=7.58) ------------------------------------------ 3x François Villon 10 AUS CEL PRE chi obf pot prince Toreador:2 3x Klaus van der Veken 9 CEL PRE aus obf tha prince Toreador:2 3x Anson 8 CEL PRE aus dom prince Toreador:1 1x Dorian Strack 4 AUS cel Toreador:1 1x Colin Flynn 3 aus cel Toreador:1 1x Isabel de Leon 3 AUS Toreador:2 Library (90 cards) Master (18) 1x Art Museum 4x Auspex 8x Blood Doll 1x KRCG News Radio 1x London Evening Star, Tabloid Newspaper 1x Powerbase: Montreal 1x Rack, The 1x Society Hunting Ground Action (13) 4x Fifth Tradition: Hospitality 4x Pulse of the Canaille 5x Third Tradition: Progeny Equipment (8) 5x Assault Rifle 1x IR Goggles 1x Pier 13, Port of Baltimore 1x Sport Bike Political Action (5) 2x Anathema 3x Archon Retainer (1) 1x Mr. Winthrop Action Modifier (7) 4x Aire of Elation 3x Bewitching Oration Reaction (23) 3x Fast Reaction 6x Forced Awakening 7x Second Tradition: Domain 7x Telepathic Misdirection Combat (15) 6x Blur 6x Disguised Weapon 3x Taste of Vitae